15.116. cdist-type__postgres_role(7) — cdist 4.10.4 documentation

# 15.116. cdist-type__postgres_role(7)

## 15.116.1. NAME

cdist-type__postgres_role - Manage postgres roles

## 15.116.2. DESCRIPTION

This cdist type allows you to create or drop postgres roles.

## 15.116.3. OPTIONAL PARAMETERS

state
  Either "present" or "absent", defaults to "present"

All other parameters map directly to the corresponding postgres createrole parameters.

password

## 15.116.4. BOOLEAN PARAMETERS

All parameter map directly to the corresponding postgres createrole parameters.

login createdb createrole superuser inherit

## 15.116.5. EXAMPLES

    __postgres_role myrole

    __postgres_role myrole --password 'secret'

    __postgres_role admin --password 'very-secret' --superuser

    __postgres_role dbcustomer --password 'bla' --createdb

## 15.116.6. SEE ALSO

cdist-type__postgres_database(7)

postgresql documentation at: <http://www.postgresql.org/docs/current/static/sql-createrole.html>.

## 15.116.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 15.116.8. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.